# CHANGELOG

## Version 0.1.3 05/05/2023
1. Fixed bug with type mismatch when calculating gcd.
2. Corrected the order of matrix and vector multiplication within the code, not in the tests.

## Version 0.1.2 04/07/2023
1. Bug with matrix multiplication fixed.

## Version 0.1.0 07/18/2022
1. First major release of the code, includes implementation of hash function and its optimization.
2. Add generator of round constants, round numbers and MDS matrix with correspond tests.